.. _package-overview:

================
Package Overview
================

AMS is an open-source packages for flexible scheduling modeling and co-simulation with
the in-house dynanic simulation engine `ANDES <https://github.com/curent/andes>`_.

AMS is currently under active development. To get involved,

* Report issues in the
  `GitHub issues page <https://github.com/CURENT/ams/issues>`_
* Learn version control with
  `the command-line git <https://git-scm.com/docs/gittutorial>`_ or
  `GitHub Desktop <https://help.github.com/en/desktop/getting-started-with-github-desktop>`_

This work was supported in part by the Engineering Research Center Program of
the National Science Foundation and the Department of Energy under NSF Award
Number EEC-1041877 and the CURENT_ Industry Partnership Program. AMS is made
open source as part of the CURENT Large Scale Testbed project.

AMS is developed and actively maintained by `Jinning Wang <https://jinningwang.github.io/>`_.
See the GitHub repository for a full list of contributors.

.. _CURENT: https://curent.utk.edu